@@ -19,9 +19,9 @@
 #include <grantlee/template.h>
 #include <grantlee/templateloader.h>
 #else
-#include <KTextTemplate/engine.h>
-#include <KTextTemplate/template.h>
-#include <KTextTemplate/templateloader.h>
+#include <KTextTemplate/Engine>
+#include <KTextTemplate/Template>
+#include <KTextTemplate/TemplateLoader>
 #endif
 
 #include <KLocalizedString>
@@ -45,7 +45,11 @@ GrantleeTemplateManager::GrantleeTemplateManager()
 
     mEngine->addTemplateLoader(mLoader);
     mEngine->addPluginPath(QStringLiteral(GRANTLEE_PLUGIN_INSTALL_DIR));
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     mEngine->addDefaultLibrary(QStringLiteral("grantlee_i18ntags"));
+#else
+    mEngine->addDefaultLibrary(QStringLiteral("ktexttemplate_i18ntags"));
+#endif
     mEngine->addDefaultLibrary(QStringLiteral("kcalendar_grantlee_plugin"));
     mEngine->setSmartTrimEnabled(true);
 }
